CircomGroth16VerifierClient

Struct CircomGroth16VerifierClient 

pub struct CircomGroth16VerifierClient<'a> {
    pub env: Env,
    pub address: Address,
    /* private fields */
}
CircomGroth16VerifierClient is a client for calling the contract defined in “CircomGroth16Verifier”.

Fields

env: Envaddress: Address

Implementations

Source

impl<'a> CircomGroth16VerifierClient<'a>

pub fn new(env: &Env, address: &Address) -> Self

pub fn set_auths(&self, auths: &'a [SorobanAuthorizationEntry]) -> Self

Set authorizations in the environment which will be consumed by contracts when they invoke Address::require_auth or Address::require_auth_for_args functions.

Requires valid signatures for the authorization to be successful. To mock auth without requiring valid signatures, use mock_auths.

See soroban_sdk::Env::set_auths for more details and examples.

pub fn mock_auths(&self, mock_auths: &'a [MockAuth<'a>]) -> Self

Mock authorizations in the environment which will cause matching invokes of Address::require_auth and Address::require_auth_for_args to pass.

See soroban_sdk::Env::set_auths for more details and examples.

pub fn mock_all_auths(&self) -> Self

Mock all calls to the Address::require_auth and Address::require_auth_for_args functions in invoked contracts, having them succeed as if authorization was provided.

See soroban_sdk::Env::mock_all_auths for more details and examples.

pub fn mock_all_auths_allowing_non_root_auth(&self) -> Self

A version of mock_all_auths that allows authorizations that are not present in the root invocation.

Refer to mock_all_auths documentation for details and prefer using mock_all_auths unless non-root authorization is required.

See soroban_sdk::Env::mock_all_auths_allowing_non_root_auth for more details and examples.

Source

impl<'a> CircomGroth16VerifierClient<'a>

pub fn verify(&self, proof: &Groth16Proof, public_inputs: &Vec<Fr>) -> bool

Verify a Groth16 proof using the stored verification key.

pub fn try_verify( &self, proof: &Groth16Proof, public_inputs: &Vec<Fr>, ) -> Result<Result<bool, <bool as TryFromVal<Env, Val>>::Error>, Result<Groth16Error, InvokeError>>

Verify a Groth16 proof using the stored verification key.